@@ -19,21 +19,14 @@ from asyncio.locks import Lock
 from concurrent.futures._base import CancelledError
 from functools import partial
 from importlib import import_module
-from signal import SIGINT
-from signal import SIGTERM
+from inspect import isclass
+from signal import SIGINT, SIGTERM
 
 import pyppeteer
 import uvloop
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
-from utils import AioPika
-from utils import AioQueue
-from utils import AioRedis
-from utils import Config
-from utils import Dict
-from utils import Logger
-from utils import Redis
-from utils import Request
-from utils import Response
+from utils import (AioPika, AioQueue, AioRedis, Config, Dict, Logger, Redis,
+                   Request, Response)
 
 asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
 
@@ -392,10 +385,16 @@ def main():
         roles=['producer', 'consumer'],
         forever=False,
     ))
-    module_name, app_name = sys.argv[1].split('.')
-    module = import_module(module_name)
-    app = getattr(module, app_name)(**opt)
-    app.start()
+    arr = sys.argv[1].split('.')
+    module = import_module(arr[0])
+    if len(arr) == 1:
+        for k, v in module.__dict__.items():
+            if not k.startswith('__') and isclass(v) and any([x.__module__ == 'processor' and x.__name__ == 'Processor' for x in v.__bases__]):
+                app = v(**opt)
+                app.start()
+    else:
+        app = getattr(module, arr[1])(**opt)
+        app.start()
 
 
 if __name__ == '__main__':
