@@ -3,6 +3,11 @@
 
 import warnings
 
+from .base_utils import (AioQueue, DefaultDict, Dict, DictUnwrapper,
+                         DictWrapper, JSONEncoder, Queue, Singleton, awaitable,
+                         ceil, connect, floor, get_ip, int2ip, int2str, ip2int,
+                         pprint, str2int, to_bytes, to_str, tqdm, yaml_dump,
+                         yaml_load)
 from .cached_property import cached_property
 from .config_utils import Config
 from .crypt import Crypt
@@ -15,10 +20,6 @@ from .http_utils import Chrome, Response, patch_connection_pool
 from .ip2region import Ip2Region
 from .log_utils import Logger, WatchedFileHandler
 from .rabbitmq import AioPika, Pika
-from .base_utils import (AioQueue, DefaultDict, Dict, DictUnwrapper, DictWrapper,
-                         JSONEncoder, Queue, Singleton, awaitable, ceil, connect,
-                         floor, get_ip, int2ip, int2str, ip2int, pprint, str2int,
-                         to_bytes, to_str, tqdm, yaml_dump, yaml_load)
 
 try:
     import pycurl  # noqa
