@@ -25,21 +25,21 @@ class Config(Dict):
 
         parser = argparse.ArgumentParser(allow_abbrev=False)
         parser.add_argument('--config', type=str, default=None)
-        args, _ = parser.parse_known_args()
-        if args.config:
-            self.update(self._load_cfg(args.config))
+        options, _ = parser.parse_known_args()
+        if options.config:
+            self.update(self._load_cfg(options.config))
 
         parser = argparse.ArgumentParser()
         for key, value in self.items():
             self._add_args(parser, key, value)
 
-        args, params = parser.parse_known_args()
+        options, params = parser.parse_known_args()
         if params:
             parsed_params = self._guess(params)
+            options.__dict__.update(parsed_params)
             logging.getLogger().info(f'{params} is parsed as: {parsed_params}')
-            args.__dict__.update(parsed_params)
 
-        for key, value in args.__dict__.items():
+        for key, value in options.__dict__.items():
             self._update(self, key, value)
 
     @staticmethod
@@ -106,15 +106,15 @@ class Config(Dict):
 
     @staticmethod
     def _guess(params):
-        args = {}
+        options = {}
         for i, param in enumerate(params):
             if param.startswith('--') and param.find('=') >= 0:
                 arr = param[2:].split('=')
-                args[arr[0]] = Config._convert(arr[1])
+                options[arr[0]] = Config._convert(arr[1])
             elif param.startswith('--no-'):
-                args[param[5:]] = False
+                options[param[5:]] = False
             elif param.startswith('--'):
-                args[param[2:]] = True
+                options[param[2:]] = True
             else:
                 values = [Config._convert(param)]
                 for j in range(1, i + 1):
@@ -123,9 +123,9 @@ class Config(Dict):
                         values.insert(0, Config._convert(key))
                     else:
                         key = key[2:]
-                        args[key] = values[0] if len(values) == 1 else values
+                        options[key] = values[0] if len(values) == 1 else values
                         break
-        return args
+        return options
 
     @staticmethod
     def _str2bool(value):
