@@ -46,8 +46,8 @@ from selenium.webdriver.support.wait import TimeoutException
 from tornado import httputil
 from tornado.httpclient import HTTPClient, HTTPRequest, HTTPResponse
 
-from .cached_property import cached_property
 from .base_utils import Dict, DictWrapper, to_bytes, to_str, tqdm
+from .cached_property import cached_property
 
 logging.getLogger("requests").setLevel(logging.WARNING)
 
@@ -194,9 +194,8 @@ class RequestMeta(type):
 class UserAgent:
 
     def __init__(self, config='user_agent.json'):
-        filename = Path(config)
-        if filename.exists():
-            self._user_agents = json.load(open(filename))
+        if Path(config).exists():
+            self._user_agents = json.load(open(config))
             self._total_agents = reduce(lambda x, y: x + y, self._user_agents.values())
 
     def __getattr__(self, key):
